@@ -2,9 +2,9 @@ import asyncio
 import json
 import logging
 import time
-import traceback
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Tuple
+import traceback
 
 import aiohttp
 from blspy import AugSchemeMPL, G1Element, G2Element, PrivateKey
@@ -18,20 +18,20 @@ from chinilla.daemon.keychain_proxy import (
     connect_to_keychain_and_validate,
     wrap_local_keychain,
 )
-from chinilla.plot_sync.delta import Delta
 from chinilla.plot_sync.receiver import Receiver
-from chinilla.pools.pool_config import PoolWalletConfig, add_auth_key, load_pool_config
+from chinilla.plot_sync.delta import Delta
+from chinilla.pools.pool_config import PoolWalletConfig, load_pool_config, add_auth_key
 from chinilla.protocols import farmer_protocol, harvester_protocol
 from chinilla.protocols.pool_protocol import (
-    AuthenticationPayload,
     ErrorResponse,
+    get_current_authentication_token,
     GetFarmerResponse,
     PoolErrorCode,
     PostFarmerPayload,
     PostFarmerRequest,
     PutFarmerPayload,
     PutFarmerRequest,
-    get_current_authentication_token,
+    AuthenticationPayload,
 )
 from chinilla.protocols.protocol_message_types import ProtocolMessageTypes
 from chinilla.server.outbound_message import NodeType, make_msg
@@ -42,16 +42,16 @@ from chinilla.types.blockchain_format.proof_of_space import ProofOfSpace
 from chinilla.types.blockchain_format.sized_bytes import bytes32
 from chinilla.util.bech32m import decode_puzzle_hash
 from chinilla.util.byte_types import hexstr_to_bytes
-from chinilla.util.config import config_path_for_filename, load_config, lock_and_load_config, save_config
+from chinilla.util.config import load_config, lock_and_load_config, save_config, config_path_for_filename
 from chinilla.util.hash import std_hash
 from chinilla.util.ints import uint8, uint16, uint32, uint64
 from chinilla.util.keychain import Keychain
 from chinilla.wallet.derive_keys import (
-    find_authentication_sk,
-    find_owner_sk,
     master_sk_to_farmer_sk,
     master_sk_to_pool_sk,
     master_sk_to_wallet_sk,
+    find_authentication_sk,
+    find_owner_sk,
 )
 from chinilla.wallet.puzzles.singleton_top_layer import SINGLETON_MOD
 
@@ -60,7 +60,6 @@ singleton_mod_hash = SINGLETON_MOD.get_tree_hash()
 log = logging.getLogger(__name__)
 
 UPDATE_POOL_INFO_INTERVAL: int = 3600
-UPDATE_POOL_INFO_FAILURE_RETRY_INTERVAL: int = 120
 UPDATE_POOL_FARMER_INFO_INTERVAL: int = 300
 
 """
@@ -257,11 +256,14 @@ class Farmer:
         self.state_changed("close_connection", {})
         if connection.connection_type is NodeType.HARVESTER:
             del self.plot_sync_receivers[connection.peer_node_id]
+            self.state_changed("harvester_removed", {"node_id": connection.peer_node_id})
 
-    async def plot_sync_callback(self, peer_id: bytes32, delta: Delta) -> None:
-        log.info(f"plot_sync_callback: peer_id {peer_id}, delta {delta}")
-        if not delta.empty():
-            self.state_changed("new_plots", await self.get_harvesters())
+    async def plot_sync_callback(self, peer_id: bytes32, delta: Optional[Delta]) -> None:
+        log.debug(f"plot_sync_callback: peer_id {peer_id}, delta {delta}")
+        receiver: Receiver = self.plot_sync_receivers[peer_id]
+        harvester_updated: bool = delta is not None and not delta.empty()
+        if receiver.initial_sync() or harvester_updated:
+            self.state_changed("harvester_update", receiver.to_dict(True))
 
     async def _pool_get_pool_info(self, pool_config: PoolWalletConfig) -> Optional[Dict]:
         try:
@@ -469,8 +471,6 @@ class Farmer:
                         # Only update the first time from GET /pool_info, gets updated from GET /farmer later
                         if pool_state["current_difficulty"] is None:
                             pool_state["current_difficulty"] = pool_info["minimum_difficulty"]
-                    else:
-                        pool_state["next_pool_info_update"] = time.time() + UPDATE_POOL_INFO_FAILURE_RETRY_INTERVAL
 
                 if time.time() >= pool_state["next_farmer_update"]:
                     pool_state["next_farmer_update"] = time.time() + UPDATE_POOL_FARMER_INFO_INTERVAL
@@ -632,13 +632,13 @@ class Farmer:
 
         return None
 
-    async def get_harvesters(self) -> Dict:
+    async def get_harvesters(self, counts_only: bool = False) -> Dict:
         harvesters: List = []
         for connection in self.server.get_connections(NodeType.HARVESTER):
             self.log.debug(f"get_harvesters host: {connection.peer_host}, node_id: {connection.peer_node_id}")
             receiver = self.plot_sync_receivers.get(connection.peer_node_id)
             if receiver is not None:
-                harvesters.append(receiver.to_dict())
+                harvesters.append(receiver.to_dict(counts_only))
             else:
                 self.log.debug(
                     f"get_harvesters invalid peer: {connection.peer_host}, node_id: {connection.peer_node_id}"
@@ -646,6 +646,12 @@ class Farmer:
 
         return {"harvesters": harvesters}
 
+    def get_receiver(self, node_id: bytes32) -> Receiver:
+        receiver: Optional[Receiver] = self.plot_sync_receivers.get(node_id)
+        if receiver is None:
+            raise KeyError(f"Receiver missing for {node_id}")
+        return receiver
+
     async def _periodically_update_pool_state_task(self):
         time_slept: uint64 = uint64(0)
         config_path: Path = config_path_for_filename(self._root_path, "config.yaml")
