@@ -207,6 +207,16 @@ class WalletStateManager:
 
         return self
 
+    def get_derivation_index(self, pubkey: G1Element, max_depth: int = 1000) -> int:
+        for i in range(0, max_depth):
+            derived = self.get_public_key(uint32(i))
+            if derived == pubkey:
+                return i
+            derived = self.get_public_key_unhardened(uint32(i))
+            if derived == pubkey:
+                return i
+        return -1
+
     def get_public_key(self, index: uint32) -> G1Element:
         return master_sk_to_wallet_sk(self.private_key, index).get_g1()
 
@@ -1078,7 +1088,7 @@ class WalletStateManager:
         wallet = self.wallets[wallet_id]
         return wallet
 
-    async def reorg_rollback(self, height: int) -> List[uint32]:
+    async def reorg_rollback(self, height: int):
         """
         Rolls back and updates the coin_store and transaction store. It's possible this height
         is the tip, or even beyond the tip.
@@ -1104,8 +1114,7 @@ class WalletStateManager:
                     remove_ids.append(wallet_id)
         for wallet_id in remove_ids:
             await self.user_store.delete_wallet(wallet_id, in_transaction=True)
-
-        return remove_ids
+            self.wallets.pop(wallet_id)
 
     async def _await_closed(self) -> None:
         await self.db_connection.close()
