@@ -23,6 +23,7 @@ from tests.setup_nodes import test_constants
 from chinilla.types.blockchain_format.sized_bytes import bytes32
 from tests.util.db_connection import DBConnection
 
+
 constants = test_constants
 
 WALLET_A = WalletTool(constants)
@@ -237,69 +238,36 @@ class TestCoinStoreWithBlocks:
         async with DBConnection(db_version) as db_wrapper:
             coin_store = await CoinStore.create(db_wrapper, cache_size=uint32(cache_size))
 
-            selected_coin: Optional[CoinRecord] = None
-            all_coins: List[Coin] = []
+            records: List[CoinRecord] = []
 
             for block in blocks:
-                all_coins += list(block.get_included_reward_coins())
                 if block.is_transaction_block():
                     removals: List[bytes32] = []
                     additions: List[Coin] = []
-                    assert block.foliage_transaction_block is not None
-                    await coin_store.new_block(
-                        block.height,
-                        block.foliage_transaction_block.timestamp,
-                        block.get_included_reward_coins(),
-                        additions,
-                        removals,
-                    )
-                    coins = list(block.get_included_reward_coins())
-                    records: List[CoinRecord] = [await coin_store.get_coin_record(coin.name()) for coin in coins]
 
-                    spend_selected_coin = selected_coin is not None
-                    if block.height != 0 and selected_coin is None:
-                        # Select the first CoinRecord which will be spent at the next transaction block.
-                        selected_coin = records[0]
-                        await coin_store._set_spent([r.name for r in records[1:]], block.height)
-                    else:
-                        await coin_store._set_spent([r.name for r in records], block.height)
+                    if block.is_transaction_block():
+                        assert block.foliage_transaction_block is not None
+                        await coin_store.new_block(
+                            block.height,
+                            block.foliage_transaction_block.timestamp,
+                            block.get_included_reward_coins(),
+                            additions,
+                            removals,
+                        )
 
-                    if spend_selected_coin:
-                        assert selected_coin is not None
-                        await coin_store._set_spent([selected_coin.name], block.height)
+                    coins = block.get_included_reward_coins()
+                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]
 
-                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]  # update coin records
+                    await coin_store._set_spent([r.name for r in records], block.height)
+
+                    records = [await coin_store.get_coin_record(coin.name()) for coin in coins]
                     for record in records:
                         assert record is not None
-                        if (
-                            selected_coin is not None
-                            and selected_coin.name == record.name
-                            and not selected_coin.confirmed_block_index < block.height
-                        ):
-                            assert not record.spent
-                        else:
-                            assert record.spent
-                            assert record.spent_block_index == block.height
+                        assert record.spent
+                        assert record.spent_block_index == block.height
 
-                    if spend_selected_coin:
-                        break
-
-            assert selected_coin is not None
-            reorg_index = selected_coin.confirmed_block_index
-
-            # Get all CoinRecords.
-            all_records: List[CoinRecord] = [await coin_store.get_coin_record(coin.name()) for coin in all_coins]
-
-            # The reorg will revert the creation and spend of many coins. It will also revert the spend (but not the
-            # creation) of the selected coin.
-            changed_records = await coin_store.rollback_to_block(reorg_index)
-            changed_coin_records = [cr.coin for cr in changed_records]
-            assert selected_coin in changed_records
-            for coin_record in all_records:
-                if coin_record.confirmed_block_index > reorg_index:
-                    assert coin_record.coin in changed_coin_records
-                if coin_record.spent_block_index > reorg_index:
-                    assert coin_record.coin in changed_coin_records
+            reorg_index = 8
+            await coin_store.rollback_to_block(reorg_index)
 
             for block in blocks:
                 if block.is_transaction_block():
@@ -309,7 +277,7 @@ class TestCoinStoreWithBlocks:
                     if block.height <= reorg_index:
                         for record in records:
                             assert record is not None
-                            assert record.spent == (record.name != selected_coin.name)
+                            assert record.spent
                     else:
                         for record in records:
                             assert record is None
